@@ -8,9 +8,9 @@
 
 # Package name      : perl5
 # Source directory  : .
-# Configuration time: Mon Jun  8 12:25:25 EDT 1998
+# Configuration time: Wed Jul  1 12:34:37 EDT 1998
 # Configured by     : doughera
-# Target system     : linux fractal 2.0.33 #1 tue feb 3 10:11:46 est 1998 i686 unknown 
+# Target system     : linux fractal 2.0.34 #1 tue jun 23 10:09:17 edt 1998 i686 unknown 
 
 Author=''
 Date='$Date'
@@ -30,9 +30,10 @@ afs='false'
 alignbytes='4'
 ansi2knr=''
 aphostname=''
+apiversion='5.00469'
 ar='ar'
-archlib='/opt/perl/lib/i686-linux-thread/5.00466'
-archlibexp='/opt/perl/lib/i686-linux-thread/5.00466'
+archlib='/opt/perl/lib/5.00469/i686-linux-thread'
+archlibexp='/opt/perl/lib/5.00469/i686-linux-thread'
 archname='i686-linux-thread'
 archobjs=''
 awk='awk'
@@ -52,7 +53,7 @@ ccdlflags='-rdynamic'
 ccflags='-D_REENTRANT -Dbool=char -DHAS_BOOL -I/usr/local/include'
 cf_by='doughera'
 cf_email='yourname@yourhost.yourplace.com'
-cf_time='Mon Jun  8 12:25:25 EDT 1998'
+cf_time='Wed Jul  1 12:34:37 EDT 1998'
 chgrp=''
 chmod=''
 chown=''
@@ -300,7 +301,7 @@ emacs=''
 eunicefix=':'
 exe_ext=''
 expr='expr'
-extensions='B DB_File Fcntl GDBM_File IO NDBM_File ODBM_File Opcode POSIX SDBM_File Socket Thread attrs'
+extensions='B DB_File Fcntl GDBM_File IO NDBM_File ODBM_File Opcode POSIX SDBM_File Socket Thread attrs Errno'
 find='find'
 firstmakefile='makefile'
 flex=''
@@ -375,14 +376,14 @@ i_varhdr='stdarg.h'
 i_vfork='undef'
 incpath=''
 inews=''
-installarchlib='/opt/perl/lib/i686-linux-thread/5.00466'
+installarchlib='/opt/perl/lib/5.00469/i686-linux-thread'
 installbin='/opt/perl/bin'
 installman1dir='/opt/perl/man/man1'
 installman3dir='/opt/perl/man/man3'
-installprivlib='/opt/perl/lib'
+installprivlib='/opt/perl/lib/5.00469/share'
 installscript='/opt/perl/script'
-installsitearch='/opt/perl/lib/site_perl/i686-linux-thread'
-installsitelib='/opt/perl/lib/site_perl'
+installsitearch='/opt/perl/lib/site_perl/5.00469/i686-linux-thread'
+installsitelib='/opt/perl/lib/site_perl/5.00469/share'
 intsize='4'
 known_extensions='B DB_File Fcntl GDBM_File IO NDBM_File ODBM_File Opcode POSIX SDBM_File Socket Thread attrs'
 ksh=''
@@ -395,7 +396,7 @@ lib_ext='.a'
 libc=''
 libperl='libperl.a'
 libpth='/usr/local/lib /lib /usr/lib'
-libs='-lnsl -lgdbm -ldbm -ldb -ldl -lm -lpthread -lc -lposix -lcrypt'
+libs='-lnsl -lndbm -lgdbm -ldbm -ldb -ldl -lm -lpthread -lc -lposix -lcrypt'
 libswanted='sfio socket inet nsl nm ndbm gdbm dbm db malloc dl dld ld sun m pthread c cposix posix ndir dir crypt ucb BSD PW x'
 line='line'
 lint=''
@@ -435,7 +436,7 @@ mv=''
 myarchname='i686-linux'
 mydomain='.yourplace.com'
 myhostname='yourhost'
-myuname='linux fractal 2.0.33 #1 tue feb 3 10:11:46 est 1998 i686 unknown '
+myuname='linux fractal 2.0.34 #1 tue jun 23 10:09:17 edt 1998 i686 unknown '
 n='-n'
 netdb_hlen_type='int'
 netdb_host_type='const char *'
@@ -444,13 +445,14 @@ netdb_net_type='unsigned long'
 nm='nm'
 nm_opt=''
 nm_so_opt='--dynamic'
+nonxs_ext='Errno'
 nroff='nroff'
 o_nonblock='O_NONBLOCK'
 obj_ext='.o'
 optimize='-O'
 orderlib='false'
 osname='linux'
-osvers='2.0.33'
+osvers='2.0.34'
 package='perl5'
 pager='/usr/bin/less'
 passcat='cat /etc/passwd'
@@ -467,8 +469,8 @@ pmake=''
 pr=''
 prefix='/opt/perl'
 prefixexp='/opt/perl'
-privlib='/opt/perl/lib'
-privlibexp='/opt/perl/lib'
+privlib='/opt/perl/lib/5.00469/share'
+privlibexp='/opt/perl/lib/5.00469/share'
 prototype='define'
 ptrsize='4'
 randbits='31'
@@ -493,10 +495,10 @@ sig_name='ZERO HUP INT QUIT ILL TRAP ABRT BUS FPE KILL USR1 SEGV USR2 PIPE ALRM
 sig_name_init='"ZERO", "HUP", "INT", "QUIT", "ILL", "TRAP", "ABRT", "BUS", "FPE", "KILL", "USR1", "SEGV", "USR2", "PIPE", "ALRM", "TERM", "STKFLT", "CHLD", "CONT", "STOP", "TSTP", "TTIN", "TTOU", "URG", "XCPU", "XFSZ", "VTALRM", "PROF", "WINCH", "IO", "PWR", "UNUSED", "IOT", "CLD", "POLL", 0'
 sig_num='0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 6, 17, 29, 0'
 signal_t='void'
-sitearch='/opt/perl/lib/site_perl/i686-linux-thread'
-sitearchexp='/opt/perl/lib/site_perl/i686-linux-thread'
-sitelib='/opt/perl/lib/site_perl'
-sitelibexp='/opt/perl/lib/site_perl'
+sitearch='/opt/perl/lib/site_perl/5.00469/i686-linux-thread'
+sitearchexp='/opt/perl/lib/site_perl/5.00469/i686-linux-thread'
+sitelib='/opt/perl/lib/site_perl/5.00469/share'
+sitelibexp='/opt/perl/lib/site_perl/5.00469/share'
 sizetype='size_t'
 sleep=''
 smail=''
@@ -521,7 +523,7 @@ stdio_filbuf=''
 stdio_ptr='((fp)->_IO_read_ptr)'
 strings='/usr/include/string.h'
 submit=''
-subversion='66'
+subversion='69'
 sysman='/usr/man/man1'
 tail=''
 tar=''
@@ -548,6 +550,7 @@ usethreads='define'
 usevfork='false'
 usrinc='/usr/include'
 uuname=''
+version='5.00469'
 vi=''
 voidflags='15'
 xlibpth='/usr/lib/386 /lib/386'
@@ -567,5 +570,5 @@ config_arg7='-Dmydomain=.yourplace.com'
 config_arg8='-Dmyhostname=yourhost'
 config_arg9='-dE'
 PATCHLEVEL=4
-SUBVERSION=66
+SUBVERSION=69
 CONFIG=true
