@@ -73,6 +73,10 @@ $Is_OS2   = $^O eq 'os2';
 $Is_Mac   = $^O eq 'MacOS';
 $Is_Win32 = $^O eq 'MSWin32';
 
+# This is for module authors to query, so they can enable 'CAPI' => 'TRUE'
+# in their Makefile.pl
+$CAPI_support = 1;
+
 require ExtUtils::MM_Unix;
 
 if ($Is_VMS) {
@@ -176,15 +180,17 @@ sub WriteMakefile {
 
 sub prompt ($;$) {
     my($mess,$def)=@_;
-    $ISA_TTY = -t STDIN && -t STDOUT ;
+    $ISA_TTY = -t STDIN && (-t STDOUT || !(-f STDOUT || -c STDOUT)) ;	# Pipe?
     Carp::confess("prompt function called without an argument") unless defined $mess;
     my $dispdef = defined $def ? "[$def] " : " ";
     $def = defined $def ? $def : "";
     my $ans;
+    local $|=1;
+    print "$mess $dispdef";
     if ($ISA_TTY) {
-	local $|=1;
-	print "$mess $dispdef";
 	chomp($ans = <STDIN>);
+    } else {
+	print "$def\n";
     }
     return $ans || $def;
 }
@@ -235,7 +241,7 @@ sub full_setup {
 
     @Attrib_help = qw/
 
-    CAPI
+    AUTHOR ABSTRACT ABSTRACT_FROM BINARY_LOCATION LICENSE_HREF CAPI
     C CCFLAGS CONFIG CONFIGURE DEFINE DIR DISTNAME DL_FUNCS DL_VARS
     EXE_FILES EXCLUDE_EXT INCLUDE_EXT NO_VC FIRST_MAKEFILE FULLPERL H
     INC INSTALLARCHLIB INSTALLBIN INSTALLDIRS INSTALLMAN1DIR
@@ -248,7 +254,7 @@ sub full_setup {
     PL_FILES PM PMLIBDIRS PREFIX
     PREREQ_PM SKIP TYPEMAPS VERSION VERSION_FROM XS XSOPT XSPROTOARG
     XS_VERSION clean depend dist dynamic_lib linkext macro realclean
-    tool_autosplit
+    tool_autosplit PPM_INSTALL_SCRIPT PPM_INSTALL_EXEC
 
     IMPORTS
 
@@ -280,7 +286,7 @@ sub full_setup {
  c_o xs_c xs_o top_targets linkext dlsyms dynamic dynamic_bs
  dynamic_lib static static_lib manifypods processPL installbin subdirs
  clean realclean dist_basics dist_core dist_dir dist_test dist_ci
- install force perldepend makefile staticmake test
+ install force perldepend makefile staticmake test ppd
 
 	  ); # loses section ordering
 
@@ -309,7 +315,7 @@ sub full_setup {
     @Get_from_Config = 
 	qw(
 	   ar cc cccdlflags ccdlflags dlext dlsrc ld lddlflags ldflags libc
-	   lib_ext obj_ext ranlib sitelibexp sitearchexp so exe_ext
+	   lib_ext obj_ext osname osvers ranlib sitelibexp sitearchexp so exe_ext
 	  );
 
     my $item;
@@ -383,8 +389,9 @@ sub ExtUtils::MakeMaker::new {
 	eval $eval;
 	if ($@){
 	    warn "Warning: prerequisite $prereq $self->{PREREQ_PM}->{$prereq} not found";
-	} else {
-	    delete $self->{PREREQ_PM}{$prereq};
+# Why is/was this 'delete' here?  We need PREREQ_PM later to make PPDs.
+#	} else {
+#	    delete $self->{PREREQ_PM}{$prereq};
 	}
     }
 #    if (@unsatisfied){
