@@ -1095,6 +1095,7 @@ OP *	ck_spair	_((OP* o));
 OP *	ck_split	_((OP* o));
 OP *	ck_subr		_((OP* o));
 OP *	ck_svconst	_((OP* o));
+OP *	ck_sysread	_((OP* o));
 OP *	ck_trunc	_((OP* o));
 
 OP *	pp_null		_((ARGSproto));
@@ -2009,17 +2010,17 @@ EXT OP * (CPERLscope(*check)[]) _((OP *op)) = {
 	ck_select,	/* sselect */
 	ck_select,	/* select */
 	ck_eof,		/* getc */
-	ck_fun,		/* read */
+	ck_sysread,	/* read */
 	ck_fun,		/* enterwrite */
 	ck_null,	/* leavewrite */
 	ck_listiob,	/* prtf */
 	ck_listiob,	/* print */
 	ck_fun,		/* sysopen */
 	ck_fun,		/* sysseek */
-	ck_fun,		/* sysread */
+	ck_sysread,	/* sysread */
 	ck_fun,		/* syswrite */
 	ck_fun,		/* send */
-	ck_fun,		/* recv */
+	ck_sysread,	/* recv */
 	ck_eof,		/* eof */
 	ck_fun,		/* tell */
 	ck_fun,		/* seek */
